@@ -25,13 +25,13 @@ class SimulationOutput(NoExtraBaseModel):
 
     include_sqlite: bool = Field(
         default=True,
-        description='Boolean to note whether a SQLite report should be generated '
+        description='Boolean to note whether a SQLite report should be requested '
             'from the simulation.'
     )
 
     include_html: bool = Field(
         default=False,
-        description='Boolean to note whether an HTML report should be generated '
+        description='Boolean to note whether an HTML report should be requested '
             'from the simulation.'
     )
 
